@@ -1,3 +1,3 @@
-from sumo_rl.environment.env import SumoEnvironment
+from sumo_rl.environment.env import SumoEnvironment, TrafficSignal
 from sumo_rl.environment.env import env, parallel_env
 from sumo_rl.environment.resco_envs import grid4x4, arterial4x4, ingolstadt1, ingolstadt7, ingolstadt21, cologne1, cologne3, cologne8
\ No newline at end of file
