@@ -6,7 +6,7 @@ if 'SUMO_HOME' in os.environ:
     tools = os.path.join(os.environ['SUMO_HOME'], 'tools')
     sys.path.append(tools)
 else:
-    sys.exit("Please declare the environment variable 'SUMO_HOME'")
+    raise ImportError("Please declare the environment variable 'SUMO_HOME'")
 import gymnasium as gym
 import numpy as np
 import pandas as pd
@@ -162,7 +162,6 @@ class SumoEnvironment(gym.Env):
 
         self.vehicles = dict()
         self.reward_range = (-float('inf'), float('inf'))
-        self.metadata = {}
         self.run = 0
         self.metrics = []
         self.out_csv_name = out_csv_name
@@ -300,7 +299,7 @@ class SumoEnvironment(gym.Env):
 
     def _compute_dones(self):
         dones = {ts_id: False for ts_id in self.ts_ids}
-        dones['__all__'] = self.sim_step > self.sim_max_time
+        dones['__all__'] = self.sim_step >= self.sim_max_time
         return dones
     
     def _compute_info(self):
@@ -345,7 +344,7 @@ class SumoEnvironment(gym.Env):
             # In SUMO, a vehicle is considered halting if its speed is below 0.1 m/s
             'system_total_stopped': sum(int(speed < 0.1) for speed in speeds),
             'system_total_waiting_time': sum(waiting_times),
-            'system_mean_waiting_time': np.mean(waiting_times),
+            'system_mean_waiting_time': 0.0 if len(vehicles) == 0 else np.mean(waiting_times),
             'system_mean_speed': 0.0 if len(vehicles) == 0 else np.mean(speeds)
         }
     
@@ -365,12 +364,15 @@ class SumoEnvironment(gym.Env):
     def close(self):
         if self.sumo is None:
             return
+        
         if not LIBSUMO:
             traci.switch(self.label)
         traci.close()
+
         if self.disp is not None:
             self.disp.stop()
             self.disp = None
+
         self.sumo = None
     
     def __del__(self):
